---
title: Understanding the Web Content Accessibility Guidelines
slug: Web/Accessibility/Understanding_WCAG
tags:
  - WCAG
  - Web Content Accessibility Guidelines
---
This set of articles provides quick explanations to help you understand the steps that need to be taken to conform to the recommendations outlined in the W3C Web Content Accessibility Guidelines 2.0 or 2.1 (or just WCAG, for the purposes of this writing).

The WCAG 2.0 and 2.1 provide a detailed set of guidelines for making web content more accessible to people with a wide variety of disabilities. It is comprehensive but incredibly detailed, and quite difficult to gain a rapid understanding of. For this reason, we have summarized the practical steps you need to take to satisfy the different recommendations, with further links to more details where required.

## The four principles

WCAG is broadly broken down into four principles — major things that web content **must be** to be considered accessible (see [Understanding the Four Principles of Accessibility](https://www.w3.org/TR/UNDERSTANDING-WCAG20/intro.html#introduction-fourprincs-head) for the WCAG definitions).

Each of the links below will take you to pages that further expand on these areas, giving you practical advice on how to write your web content so it conforms to the success criteria outlined in each of the WCAG 2.0 and 2.1 guidelines that further sub-divides each principle.

- [Perceivable:](/en-US/docs/Web/Accessibility/Understanding_WCAG/Perceivable) Users must be able to perceive it in some way, using one or more of their senses.
- [Operable](/en-US/docs/Web/Accessibility/Understanding_WCAG/Operable): Users must be able to control UI elements (e.g. buttons must be clickable in some way — mouse, keyboard, voice command, etc.).
- [Understandable](/en-US/docs/Web/Accessibility/Understanding_WCAG/Understandable): The content must be understandable to its users.
- [Robust](/en-US/docs/Web/Accessibility/Understanding_WCAG/Robust): The content must be developed using well-adopted web standards that will work across different browsers, now and in the future.

## Should I use WCAG 2.0 or 2.1?

WCAG 2.1 is the most recent and relevant accessibility standard. Use WCAG 2.1 to help more people with disabilities and reduce the future legal risk for web site owners. Target WCAG 2.0 first when allocating resources. Then step up to WCAG 2.1.

### What is WCAG 2.1?

WCAG 2.1 was published as an official recommendation on 05 June 2018. The European Union (EU) adopted WCAG 2.1 as the digital accessibility standard in September 2018. W3C published a press release [WCAG 2.1 Adoption in Europe](https://www.w3.org/blog/2018/09/wcag-2-1-adoption-in-europe/).

WCAG 2.1 includes:

- all of WCAG 2.0 (verbatim, word-for-word)
- 17 new Success Criteria at the A / AA / AAA levels primarily addressing user needs in these areas:

  - Mobile Accessibility
  - Low Vision
  - Cognitive

- Read more about WCAG 2.1:

  - W3C/WAI: [What's new in WCAG 2.1?](https://www.w3.org/WAI/standards-guidelines/wcag/new-in-21/)
  - Deque: [WCAG 2.1: What is Next for Accessibility Guidelines](https://www.deque.com/blog/wcag-2-1-what-is-next-for-accessibility-guidelines/)
  - TPG: [Web Content Accessibility Guidelines (WCAG) 2.1](https://developer.paciellogroup.com/blog/2018/06/web-content-accessibility-guidelines-wcag-2-1/)

## Legal standing

This guide is intended to provide practical information to help you build better, more accessible websites. However, we are not lawyers, and none of this constitutes legal advice. If you are worried about the legal implications of web accessibility, we'd recommend that you check the specific legislation governing accessibility for the web/public resources in your country or locale, and seek the advice of a qualified lawyer.

[What is accessibility?](/en-US/docs/Learn/Accessibility/What_is_accessibility) and particularity the [Accessibility guidelines and the law](/en-US/docs/Learn/Accessibility/What_is_accessibility#accessibility_guidelines_and_the_law) section provide more related information.
