---
title: MediaStreamTrack
slug: Web/API/MediaStreamTrack
tags:
  - API
  - Audio
  - Interface
  - Media
  - Media Capture and Streams API
  - Media Streams API
  - MediaStreamTrack
  - Reference
  - Video
  - WebRTC
browser-compat: api.MediaStreamTrack
---
{{APIRef("Media Capture and Streams")}}

The **`MediaStreamTrack`** interface represents a single media track within a stream; typically, these are audio or video tracks, but other track types may exist as well.

{{InheritanceDiagram}}

## Properties

In addition to the properties listed below, `MediaStreamTrack` has constrainable properties which can be set using {{domxref("MediaStreamTrack.applyConstraints", "applyConstraints()")}} and accessed using {{domxref("MediaStreamTrack.getConstraints", "getConstraints()")}} and {{domxref("MediaStreamTrack.getSettings", "getSettings()")}}. See [Capabilities, constraints, and settings](/en-US/docs/Web/API/Media_Streams_API/Constraints) to learn how to correctly work with constrainable properties. Not doing so correctly will result in your code being unreliable.

- {{domxref("MediaStreamTrack.contentHint")}}
  - : A string that may be used by the web application to provide a hint as to what type of content the track contains to guide how it should be treated by API consumers.
- {{domxref("MediaStreamTrack.enabled")}}

  - : A Boolean whose value of `true` if the track is enabled, that is allowed to render the media source stream; or `false` if it is disabled, that is not rendering the media source stream but silence and blackness. If the track has been disconnected, this value can be changed but has no more effect.

    > **Note:** You can implement standard "mute" functionality by setting `enabled` to `false`. The `muted` property refers to a condition in which there's no media because of a technical issue.

- {{domxref("MediaStreamTrack.id")}} {{readonlyInline}}
  - : Returns a {{domxref("DOMString")}} containing a unique identifier (GUID) for the track; it is generated by the browser.
- {{domxref("MediaStreamTrack.kind")}} {{readonlyInline}}
  - : Returns a {{domxref("DOMString")}} set to `"audio"` if the track is an audio track and to `"video"`, if it is a video track. It doesn't change if the track is deassociated from its source.
- {{domxref("MediaStreamTrack.label")}} {{readonlyInline}}
  - : Returns a {{domxref("DOMString")}} containing a user agent-assigned label that identifies the track source, as in `"internal microphone"`. The string may be left empty and is empty as long as no source has been connected. When the track is deassociated from its source, the label is not changed.
- {{domxref("MediaStreamTrack.muted")}} {{readonlyInline}}

  - : Returns a Boolean value indicating whether the track is unable to provide media data due to a technical issue.

    > **Note:** You can implement standard "mute" functionality by setting `enabled` to `false`, and unmute the media by setting it back to `true` again.

- {{domxref("MediaStreamTrack.readyState")}} {{readonlyInline}}

  - : Returns an enumerated value giving the status of the track. This will be one of the following values:

    - `"live"` which indicates that an input is connected and does its best-effort in providing real-time data. In that case, the output of data can be switched on or off using the {{domxref("MediaStreamTrack.enabled", "enabled")}} attribute.
    - `"ended"` which indicates that the input is not giving any more data and will never provide new data.

- {{domxref("MediaStreamTrack.remote")}} {{readonlyInline}} {{deprecated_inline}}
  - : Returns a Boolean with a value of `true` if the track is sourced by a {{domxref("RTCPeerConnection")}}, `false` otherwise.

## Methods

- {{domxref("MediaStreamTrack.applyConstraints()")}}
  - : Lets the application specify the ideal and/or ranges of acceptable values for any number of the available constrainable properties of the `MediaStreamTrack`.
- {{domxref("MediaStreamTrack.clone()")}}
  - : Returns a duplicate of the `MediaStreamTrack`.
- {{domxref("MediaStreamTrack.getCapabilities()")}}
  - : Returns the a list of constrainable properties available for the `MediaStreamTrack`.
- {{domxref("MediaStreamTrack.getConstraints()")}}
  - : Returns a {{domxref('MediaTrackConstraints')}} object containing the currently set constraints for the track; the returned value matches the constraints last set using {{domxref("MediaStreamTrack.applyConstraints", "applyConstraints()")}}.
- {{domxref("MediaStreamTrack.getSettings()")}}
  - : Returns a {{domxref("MediaTrackSettings")}} object containing the current values of each of the `MediaStreamTrack`'s constrainable properties.
- {{domxref("MediaStreamTrack.stop()")}}
  - : Stops playing the source associated to the track, both the source and the track are deassociated. The track state is set to `ended`.

## Events

Listen to these events using {{domxref("EventTarget.addEventListener", "addEventListener()")}} or by assigning an event listener to the `oneventname` property of this interface:

- {{domxref("MediaStreamTrack/ended_event", "ended")}}
  - : Sent when playback of the track ends (when the value {{domxref("MediaStreamTrack.readyState", "readyState")}} changes to `ended`).
- {{domxref("MediaStreamTrack/mute_event", "mute")}}
  - : Sent to the `MediaStreamTrack` when the value of the {{domxref("MediaStreamTrack.muted", "muted")}} property is changed to `true`, indicating that the track is unable to provide data temporarily (such as when the network is experiencing a service malfunction).
- {{domxref("MediaStreamTrack/overconstrained_event", "overconstrained")}} {{deprecated_inline}}
  - : Sent when the constraints specified for the track cause the track to be incompatible and therefore to not be used.
- {{domxref("MediaStreamTrack/unmute_event", "unmute")}}
  - : Sent to the track when data becomes available again, ending the `muted` state.

## Specifications

{{Specifications}}

## Browser compatibility

{{Compat}}

## See also

- [Media Capture and Streams API](/en-US/docs/Web/API/Media_Streams_API)
- {{domxref("MediaStream")}}
