---
title: JavaScript language resources
slug: Web/JavaScript/Language_Resources
tags:
  - Advanced
  - ECMA
  - Guide
  - JavaScript
---
{{JsSidebar}}

**ECMAScript** is the scripting language that forms the basis of [JavaScript](/en-US/docs/Web/JavaScript). ECMAScript standardized by the [ECMA International](https://www.ecma-international.org/) standards organization in the **ECMA-262 and ECMA-402 specifications**. The following ECMAScript standards have been approved or are being worked on:

<table class="standard-table">
  <tbody>
    <tr>
      <th>Name</th>
      <th>Links</th>
      <th>Release date</th>
      <th>Description</th>
    </tr>
    <tr>
      <th colspan="4">Current editions</th>
    </tr>
    <tr>
      <td>ECMA-262 11th Edition</td>
      <td>
        <p>
          <a
            href="https://www.ecma-international.org/publications/files/ECMA-ST/ECMA-262.pdf"
            >PDF</a
          >,
          <a href="https://ecma-international.org/ecma-262/11.0/index.html"
            >HTML</a
          >, <a href="https://tc39.github.io/ecma262/">Working draft</a>,
          <a href="https://github.com/tc39/ecma262">repository</a>
        </p>
      </td>
      <td>2020</td>
      <td>ECMAScript 2020 Language Specification</td>
    </tr>
    <tr>
      <td>ECMA-262 10th Edition</td>
      <td>
        <p>
          <a
            href="https://www.ecma-international.org/publications/files/ECMA-ST/ECMA-262.pdf"
            >PDF</a
          >,
          <a href="https://ecma-international.org/ecma-262/10.0/index.html"
            >HTML</a
          >, <a href="https://tc39.github.io/ecma262/">Working draft</a>,
          <a href="https://github.com/tc39/ecma262">repository</a>
        </p>
      </td>
      <td>2019</td>
      <td>ECMAScript 2019 Language Specification</td>
    </tr>
    <tr>
      <td>ECMA-262 9th Edition</td>
      <td>
        <p>
          <a
            href="http://ecma-international.org/publications/files/ECMA-ST/Ecma-262.pdf"
            >PDF</a
          >,
          <a href="http://ecma-international.org/ecma-262/9.0/index.html#Title"
            >HTML</a
          >, <br /><a href="https://tc39.github.io/ecma262/">Working draft</a>,
          <a href="https://github.com/tc39/ecma262">repository</a>
        </p>
      </td>
      <td>2018</td>
      <td>ECMAScript 2018 Language Specification</td>
    </tr>
    <tr>
      <td>ECMA-402 5th Edition</td>
      <td>
        <a href="https://tc39.github.io/ecma402/">Working draft</a>,
        <a href="https://github.com/tc39/ecma402">repository</a>
      </td>
      <td>2018</td>
      <td>ECMAScript 2018 Internationalization API Specification</td>
    </tr>
    <tr>
      <th colspan="4">Obsolete/historical editions</th>
    </tr>
    <tr>
      <td>ECMA-262</td>
      <td>
        <a
          href="https://www.ecma-international.org/publications/files/ECMA-ST-ARCH/ECMA-262,%201st%20edition,%20June%201997.pdf"
          >PDF</a
        >
      </td>
      <td>June 1997</td>
      <td>
        ECMAScript: A general purpose, cross-platform programming language. This
        was the first version of the ECMAScript standard.
      </td>
    </tr>
    <tr>
      <td>ECMA-262 2nd Edition</td>
      <td>
        <a
          href="https://www.ecma-international.org/publications/files/ECMA-ST-ARCH/ECMA-262,%202nd%20edition,%20August%201998.pdf"
          >PDF</a
        >
      </td>
      <td>August 1998</td>
      <td>
        ECMAScript Language Specification. This is the second revision of the
        ECMAScript standard; also ISO standard 16262.
      </td>
    </tr>
    <tr>
      <td>ECMA-262 3rd Edition</td>
      <td>
        <a
          href="https://www.ecma-international.org/publications/files/ECMA-ST-ARCH/ECMA-262,%203rd%20edition,%20December%201999.pdf"
          >PDF</a
        >
      </td>
      <td>December 1999</td>
      <td>
        ECMAScript Language Specification. This is the third revision of the
        ECMAScript standard; corresponds to JavaScript 1.5.<br />See also the
        <a href="https://www.mozilla.org/js/language/E262-3-errata.html"
          >errata</a
        >
      </td>
    </tr>
    <tr>
      <td>ECMA-262 5th Edition</td>
      <td>
        <a
          href="https://www.ecma-international.org/publications/files/ECMA-ST-ARCH/ECMA-262%205th%20edition%20December%202009.pdf"
          >PDF</a
        >
      </td>
      <td>December 2009</td>
      <td>
        ECMAScript Language Specification. This is the fifth revision of the
        ECMAScript standard.<br />See also the
        <a
          href="https://wiki.ecmascript.org/doku.php?id=es3.1:es3.1_proposal_working_draft"
          >ES5 errata</a
        >
        and
        <a
          href="/en-US/docs/JavaScript/ECMAScript_5_support_in_Mozilla"
          title="JavaScript/ECMAScript 5 support in Mozilla"
          >ECMAScript 5 support in Mozilla</a
        >
      </td>
    </tr>
    <tr>
      <td>ECMA-262 5.1 Edition</td>
      <td>
        <a href="http://www.ecma-international.org/ecma-262/5.1/ECMA-262.pdf"
          >PDF</a
        >, <a href="https://www.ecma-international.org/ecma-262/5.1/">HTML</a>
      </td>
      <td>June 2011</td>
      <td>
        This version is fully aligned with the third edition of the
        international standard
        <a
          href="https://www.iso.org/iso/iso_catalogue/catalogue_tc/catalogue_detail.htm?csnumber=55755"
          >ISO/IEC 16262:2011</a
        >.<br />It includes ES5 errata fixes, no new features.
      </td>
    </tr>
    <tr>
      <td>ECMA-402 1st Edition</td>
      <td>
        <a href="https://ecma-international.org/ecma-402/1.0/ECMA-402.pdf"
          >PDF</a
        >,
        <a href="https://ecma-international.org/ecma-402/1.0/index.html"
          >HTML</a
        >
      </td>
      <td>December 2012</td>
      <td>ECMAScript Internationalization API Specification</td>
    </tr>
    <tr>
      <td>ECMA-262 6th Edition</td>
      <td>
        <a href="https://www.ecma-international.org/ecma-262/6.0/ECMA-262.pdf"
          >PDF</a
        >,
        <a href="https://www.ecma-international.org/ecma-262/6.0/index.html"
          >HTML</a
        >
      </td>
      <td>June 2015</td>
      <td>ECMAScript 2015 Language Specification</td>
    </tr>
    <tr>
      <td>ECMA-402 2nd Edition</td>
      <td>
        <a href="https://www.ecma-international.org/ecma-402/2.0/ECMA-402.pdf"
          >PDF</a
        >
      </td>
      <td>June 2015</td>
      <td>ECMAScript 2015 Internationalization API Specification</td>
    </tr>
    <tr>
      <td>ECMA-262 7th Edition</td>
      <td>
        <a href="https://www.ecma-international.org/ecma-262/7.0/">HTML</a>
      </td>
      <td>June 2016</td>
      <td>ECMAScript 2016 Language Specification</td>
    </tr>
    <tr>
      <td>ECMA-402 3rd Edition</td>
      <td>
        <a href="https://www.ecma-international.org/ecma-402/3.0/">HTML</a>
      </td>
      <td>June 2016</td>
      <td>ECMAScript 2016 Internationalization API Specification</td>
    </tr>
    <tr>
      <td>ECMA-262 8th Edition</td>
      <td>
        <a href="https://www.ecma-international.org/ecma-262/8.0/">HTML</a>
      </td>
      <td>June 2017</td>
      <td>ECMAScript 2017 Language Specification</td>
    </tr>
    <tr>
      <td>ECMA-402 4th Edition</td>
      <td>
        <a href="https://www.ecma-international.org/ecma-402/4.0/">HTML</a>
      </td>
      <td>June 2017</td>
      <td>ECMAScript 2017 Internationalization API Specification</td>
    </tr>
  </tbody>
</table>

**ES.Next** is a dynamic name that refers to whatever the next version is at the time of writing. ES.Next features are more correctly called proposals, because, by definition, the specification has not been finalized yet.

See [Wikipedia ECMAScript entry](https://en.wikipedia.org/wiki/ECMAScript) for more information on ECMAScript history.

## Related resources

There are a variety of ways you can participate in or just track current work on the ECMAScript Language Specification and the ECMAScript Internationalization API Specification and related resources:

Resource                          | Description
----------------------------------|----------------------------------
https://github.com/tc39/ecma262   | ECMAScript Language Specification repo
https://github.com/tc39/ecma402   | ECMAScript Internationalization API Specification repo
https://github.com/tc39/proposals | ECMAScript proposals repo
https://github.com/tc39/test262   | ECMAScript conformance test suite repo
https://es.discourse.group/       | ECMAScript spec discussion; current mailing list
https://esdiscuss.org/            | ECMAScript spec discussion; historical mailing-list archives (until March 2021)
